@@ -1,15 +1,17 @@
 from __future__ import annotations
 
 from enum import StrEnum
+from typing import Annotated
 
-from langgraph.graph import MessagesState
+from langchain_core.messages import AnyMessage
+from langgraph.graph.message import add_messages
 from pydantic import BaseModel, Field
 
 
-class AgentGraphState(MessagesState):
+class AgentGraphState(BaseModel):
     """Agent Graph state for standard loop execution."""
 
-    pass
+    messages: Annotated[list[AnyMessage], add_messages] = []
 
 
 class AgentGraphNode(StrEnum):
